#! /usr/local/bin/perl -w
#
#
# main for SAS perl tasks.
#
require 5;
use strict;
use Getopt::Long;
Getopt::Long::Configure ("pass_through");
use SAS::error;
## At build time the following strings (enclosed in --, that is
## -string-) are replaced: 
##  taskname
##  version
##  release
##  aka
## Make sure they do not occur anywhere else in main.pl unless you
## want them to be replaced.
##  taskname also occurs at the end of main.pl
##
my $name = "-taskname-";
SAS::error::client($name);
my $VERSION = "-version-";
my $RELEASE = "-release-";
my $AKA = "-aka-";

## 
## Standard options: these follow taskmain.
## At the moment only the long name versions are implemented.
##
## -a|--ccfpath <dir1>[:<dir2>...] --> SAS_CCFPATH
## -f|--ccffiles <f1> [<f2>...] --> cannot be implemented
## -c|--noclobber --> SAS_CLOBBER
## -d|--dialog --> tool(sasdialog)
## -h|--help --> tool(listparams)
## -i|--ccf <cif> --> SAS_CCF
## -m|--manpage --> sashelp
## -o|--odf <sumfile> --> SAS_ODF
## -V|--verbosity <level> -- SAS_VERBOSITY
## -v|--version --> local implementation
##

my ($ccfpath, $noclobber, $dialog, $help, $ccf, $manpage, $odf, $verbosity, $version);

exit(1) unless
    GetOptions("ccfpath=s" => \$ccfpath,
	       "noclobber" => \$noclobber,
	       "dialog" => \$dialog,
	       "help" => \$help,
	       "ccf=s" => \$ccf,
	       "manpage" => \$manpage,
	       "odf=s" => \$odf,
	       "verbosity=i" => \$verbosity,
	       "version" => \$version,
	      );

$ENV{SAS_CCFPATH} = $ccfpath if($ccfpath);
$ENV{SAS_CLOBBER} = 0 if($noclobber);
$ENV{SAS_CCF} = $ccf if($ccf);
$ENV{SAS_ODF} = $odf if($odf);
$ENV{SAS_VERBOSITY} = $verbosity if($verbosity);

use SAS::param;


if($version){
    print "$name-$VERSION [$RELEASE-$AKA]\n";
    exit(0);
}
if($manpage){
    system("sashelp --doc=$name");
    my $x = $? >> 8; # perldoc -f system
    exit($x);
}
if($help){
    system("listparams $name");
    my $x = $? >> 8;
    exit($x);
}
if($dialog){
    system("sasdialog $name");
    my $x = $? >> 8;
    exit($x);
}

&-taskname-();

